@@ -1,4 +1,4 @@
-`FOBI` <-
+FOBI <-
 function(X, na.action = na.fail)
     {
     X <- na.action(X)
@@ -12,20 +12,21 @@ function(X, na.action = na.fail)
     
     EVD.COV <- eigen(COV, symmetric=TRUE)
     
-    COV.inv.sqrt <-  EVD.COV$vectors %*% diag((1/EVD.COV$values)^0.5) %*% t(EVD.COV$vectors)
+    COV.inv.sqrt <-  EVD.COV$vectors %*% tcrossprod(diag((1/EVD.COV$values)^0.5),EVD.COV$vectors)
     Y <- tcrossprod(X, COV.inv.sqrt)
     r <- sqrt(rowSums(Y^2))
     Y <- r * Y
 
-    COV4 <- crossprod(Y)/n
+    COV4 <- crossprod(Y)/(n*(p+2))
     
     EVD.COV4  <- eigen(COV4, symmetric=TRUE)
     W <- crossprod(EVD.COV4$vectors, COV.inv.sqrt)
-    W <- diag(sign(rowMeans(W)))%*%W
-
+    #W <- diag(sign(rowMeans(W)))%*%W
+    W <- sweep(W, 1, sign(rowMeans(W)), "*")
+    
     S <- tcrossprod(X, W)
     colnames(S) <- paste("IC.", 1:p, sep="")
-    res<-list(W=W, EV=EVD.COV4$values, Xmu=Col.center, S=S)
+    res <- list(W=W, EV=EVD.COV4$values, Xmu=Col.center, S=S)
     class(res) <- "bss"
     return(res)
     }
